@@ -16,28 +16,27 @@ class ENSConversions(ConverterAPI):
     @cached_property
     def mainnet_provider(self) -> Optional[Web3Provider]:
         provider = self.network_manager.active_provider
-        if (
-            not provider
-            or not isinstance(provider, Web3Provider)
-            or not provider.network.name == "mainnet"
-        ):
-            provider = self.network_manager.get_provider_from_choice("ethereum:mainnet")
+        if provider and isinstance(provider, Web3Provider) and provider.network.name == "mainnet":
+            return provider
 
-            if not isinstance(provider, Web3Provider):
-                logger.warning(
-                    "Unable to connect to mainnet provider to "
-                    "perform ENS lookup (must be a Web3Provider)"
-                )
-                return None
+        # Connect to mainnet for ENS resolution
+        # NOTE: May not work unless the user configures their default mainnet provider.
+        provider = self.network_manager.get_provider_from_choice("ethereum:mainnet")
+        if not isinstance(provider, Web3Provider):
+            logger.warning(
+                "Unable to connect to mainnet provider to "
+                "perform ENS lookup (must be a Web3Provider)"
+            )
+            return None
 
-            try:
-                provider.connect()
-            except ProviderError:
-                logger.warning(
-                    "Unable to connect to mainnet provider to perform ENS lookup. "
-                    "Try changing your default mainnet provider."
-                )
-                return None
+        try:
+            provider.connect()
+        except ProviderError:
+            logger.warning(
+                "Unable to connect to mainnet provider to perform ENS lookup. "
+                "Try changing your default mainnet provider."
+            )
+            return None
 
         return provider
 
@@ -60,7 +59,11 @@ class ENSConversions(ConverterAPI):
                 if not provider:
                     return False
 
-                address = provider.web3.ens.address(value)
+                ens = provider.web3.ens
+                if not ens:
+                    return False
+
+                address = ens.address(value)
 
                 if address is not None:
                     self.address_cache[value] = address
@@ -80,6 +83,11 @@ class ENSConversions(ConverterAPI):
             raise ValueError(f"Unable to convert ENS value '{value}'.")
 
         # TODO: Switch to using ENS SDK
-        address = provider.web3.ens.address(value)
+        ens = provider.web3.ens
+        if not ens:
+            # Should never get here.
+            raise ValueError(f"Unable to convert ENS value '{value}'.")
+
+        address = ens.address(value)
         self.address_cache[value] = address
         return address
